| Title: | Documentation for 'distr' Family of R Packages |
|---|---|
| Description: | Provides documentation in form of a common vignette to packages 'distr', 'distrEx', 'distrMod', 'distrSim', 'distrTEst', 'distrTeach', and 'distrEllipse'. |
| Authors: | Florian Camphausen [ctb] (contributed as student to the documented packages in the initial phase --2005), Matthias Kohl [aut, cph], Peter Ruckdeschel [cre, cph], Thomas Stabla [ctb] (contributed as student to the documented packages in the initial phase --2005) |
| Maintainer: | Peter Ruckdeschel <[email protected]> |
| License: | LGPL-3 |
| Version: | 2.8.5 |
| Built: | 2026-05-07 08:29:28 UTC |
| Source: | https://github.com/r-forge/distr |
distrDoc provides documentation in form of a common vignette to packages distr, distrEx, distrSim, distrTEst, distrTeach, distrMod, and distrEllipse.
| Package: | distrDoc |
| Version: | 2.8.5 |
| Date: | 2025-01-11 |
| Depends: | R(>= 3.4) |
| Imports: | distr(>= 2.2.0), distrEx(>= 2.2.0), distrSim(>= 2.2.0), distrTEst(>= 2.2.0),distrTeach(>= 2.2.0), RandVar(>= 0.7), distrMod(>= 2.2.0), MASS, methods, startupmsg(>= 1.0.0) |
| Suggests: | Biobase, knitr |
| ByteCompile: | yes |
| License: | LGPL-3 |
| URL: | https://distr.r-forge.r-project.org/ |
| VCS/SVNRevision: | 1499 |
The idea to split off a common vignette for a set of packages in a particular documentation package is due to Seth Falcon.
You may suppress the start-up banner/message completely by setting options("StartupBanner"="off")
somewhere before loading this package by library or require in your R-code / R-session.
If option "StartupBanner" is not defined (default) or setting
options("StartupBanner"=NULL) or options("StartupBanner"="complete")
the complete start-up banner is displayed.
For any other value of option "StartupBanner" (i.e., not in c(NULL,"off","complete"))
only the version information is displayed.
The same can be achieved by wrapping the library or require call into
either suppressStartupMessages() or onlytypeStartupMessages(.,atypes="version").
As for general packageStartupMessage's, you may also suppress all
the start-up banner by wrapping the library or require
call into suppressPackageStartupMessages() from
startupmsg-version 0.5 on.
Note: The first two numbers of package versions do not necessarily reflect package-individual development, but rather are chosen for the distrXXX family as a whole in order to ease updating "depends" information.
Peter Ruckdeschel [email protected],
Thomas Stabla [email protected],
Florian Camphausen [email protected],
Matthias Kohl [email protected]
Maintainer: Peter Ruckdeschel [email protected]
see mails "[Rd] package vignettes, suggests and R CMD check"
on r-devel by Seth Falcon,
https://stat.ethz.ch/pipermail/r-devel/2006-November/043702.html,
https://stat.ethz.ch/pipermail/r-devel/2006-November/043705.html,
and by the author,
https://stat.ethz.ch/pipermail/r-devel/2006-November/043700.html,
https://stat.ethz.ch/pipermail/r-devel/2006-November/043703.html\ cr
## Not run: ## Open the distr vignette vignette("distr") ## End(Not run)## Not run: ## Open the distr vignette vignette("distr") ## End(Not run)